@@ -4,7 +4,7 @@ use v5.14;
 use warnings;
 use utf8;
 
-our $VERSION = "2.11";
+our $VERSION = "2.1101";
 
 use Data::Dumper;
 $Data::Dumper::Sortkeys = 1;
@@ -103,29 +103,29 @@ our %TABSTYLE = (
     }
     space  => [ ' ', ' ' ],
     dot    => [ '.', '.' ],
-    symbol => [ "\N{SYMBOL FOR HORIZONTAL TABULATION}",
-		"\N{SYMBOL FOR SPACE}" ],
-    shade  => [ "\N{MEDIUM SHADE}",
-		"\N{LIGHT SHADE}" ],
-    block  => [ "\N{LOWER ONE QUARTER BLOCK}",
-		"\N{LOWER ONE EIGHTH BLOCK}" ],
-    bar    => [ "\N{BOX DRAWINGS HEAVY RIGHT}",
-		"\N{BOX DRAWINGS LIGHT HORIZONTAL}" ],
-    dash   => [ "\N{BOX DRAWINGS HEAVY RIGHT}",
-		"\N{BOX DRAWINGS LIGHT DOUBLE DASH HORIZONTAL}" ],
+    symbol => [ "\N{SYMBOL FOR HORIZONTAL TABULATION}",			    # ␉
+		"\N{SYMBOL FOR SPACE}" ],				    # ␠
+    shade  => [ "\N{MEDIUM SHADE}",					    # ▒
+		"\N{LIGHT SHADE}" ],					    # ░
+    block  => [ "\N{LOWER ONE QUARTER BLOCK}",				    # ▂
+		"\N{LOWER ONE EIGHTH BLOCK}" ],				    # ▁
+    bar    => [ "\N{BOX DRAWINGS HEAVY RIGHT}",				    # ╺
+		"\N{BOX DRAWINGS LIGHT HORIZONTAL}" ],			    # ─
+    dash   => [ "\N{BOX DRAWINGS HEAVY RIGHT}",				    # ╺
+		"\N{BOX DRAWINGS LIGHT DOUBLE DASH HORIZONTAL}" ],	    # ╌
 
-    arrow        => "\N{RIGHTWARDS ARROW}",
-    double_arrow => "\N{RIGHTWARDS DOUBLE ARROW}",
-    triple_arrow => "\N{RIGHTWARDS TRIPLE ARROW}",
-    white_arrow  => "\N{RIGHTWARDS WHITE ARROW}",
-    wave_arrow   => "\N{RIGHTWARDS WAVE ARROW}",
-    circle_arrow => "\N{CIRCLED HEAVY WHITE RIGHTWARDS ARROW}",
-    curved_arrow => "\N{HEAVY BLACK CURVED DOWNWARDS AND RIGHTWARDS ARROW}",
-    shadow_arrow => "\N{HEAVY UPPER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW}",
-    squat_arrow  => "\N{SQUAT BLACK RIGHTWARDS ARROW}",
-    squiggle     => "\N{RIGHTWARDS SQUIGGLE ARROW}",
-    harpoon      => "\N{RIGHTWARDS HARPOON WITH BARB UPWARDS}",
-    cuneiform    => "\N{CUNEIFORM SIGN TAB}",
+    arrow        => "\N{RIGHTWARDS ARROW}",				    # →
+    double_arrow => "\N{RIGHTWARDS DOUBLE ARROW}",			    # ⇒
+    triple_arrow => "\N{RIGHTWARDS TRIPLE ARROW}",			    # ⇛
+    white_arrow  => "\N{RIGHTWARDS WHITE ARROW}",			    # ⇨
+    wave_arrow   => "\N{RIGHTWARDS WAVE ARROW}",			    # ↝
+    circle_arrow => "\N{CIRCLED HEAVY WHITE RIGHTWARDS ARROW}",		    # ➲
+    curved_arrow => "\N{HEAVY BLACK CURVED DOWNWARDS AND RIGHTWARDS ARROW}",# ➥
+    shadow_arrow => "\N{HEAVY UPPER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW}",# ➮
+    squat_arrow  => "\N{SQUAT BLACK RIGHTWARDS ARROW}",			    # ➧
+    squiggle     => "\N{RIGHTWARDS SQUIGGLE ARROW}",			    # ⇝
+    harpoon      => "\N{RIGHTWARDS HARPOON WITH BARB UPWARDS}",		    # ⇀
+    cuneiform    => "\N{CUNEIFORM SIGN TAB}",				    # 𒋰
 
     );
 
@@ -398,7 +398,7 @@ sub fold {
 	while ($m > 0 and
 	       m{\A (?<color> ${color_re}*+)
 	            (?<runin> $prohibition_re{head})
-	            (?<reset> ${reset_re}*)
+	            (?<reset> (?: $erase_re* $reset_re+ $erase_re* )? )
 	       }xp) {
 	    my $w = vwidth $+{runin};
 	    last if ($m -= $w) < 0;
@@ -511,7 +511,7 @@ Text::ANSI::Fold - Text folding library supporting ANSI terminal sequence and As
 
 =head1 VERSION
 
-Version 2.11
+Version 2.1101
 
 =head1 SYNOPSIS
 
@@ -787,18 +787,17 @@ Currently these names are available.
                 "\N{BOX DRAWINGS LIGHT DOUBLE DASH HORIZONTAL}" ],
 
 Below are styles providing same character for both tabhead and
-tabspace.  Convert underscore (C<_>) to dash (C<->) like
-C<double-arrow>.
+tabspace.
 
     arrow        => "\N{RIGHTWARDS ARROW}",
-    double_arrow => "\N{RIGHTWARDS DOUBLE ARROW}",
-    triple_arrow => "\N{RIGHTWARDS TRIPLE ARROW}",
-    white_arrow  => "\N{RIGHTWARDS WHITE ARROW}",
-    wave_arrow   => "\N{RIGHTWARDS WAVE ARROW}",
-    circle_arrow => "\N{CIRCLED HEAVY WHITE RIGHTWARDS ARROW}",
-    curved_arrow => "\N{HEAVY BLACK CURVED DOWNWARDS AND RIGHTWARDS ARROW}",
-    shadow_arrow => "\N{HEAVY UPPER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW}",
-    squat_arrow  => "\N{SQUAT BLACK RIGHTWARDS ARROW}",
+    double-arrow => "\N{RIGHTWARDS DOUBLE ARROW}",
+    triple-arrow => "\N{RIGHTWARDS TRIPLE ARROW}",
+    white-arrow  => "\N{RIGHTWARDS WHITE ARROW}",
+    wave-arrow   => "\N{RIGHTWARDS WAVE ARROW}",
+    circle-arrow => "\N{CIRCLED HEAVY WHITE RIGHTWARDS ARROW}",
+    curved-arrow => "\N{HEAVY BLACK CURVED DOWNWARDS AND RIGHTWARDS ARROW}",
+    shadow-arrow => "\N{HEAVY UPPER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW}",
+    squat-arrow  => "\N{SQUAT BLACK RIGHTWARDS ARROW}",
     squiggle     => "\N{RIGHTWARDS SQUIGGLE ARROW}",
     harpoon      => "\N{RIGHTWARDS HARPOON WITH BARB UPWARDS}",
     cuneiform    => "\N{CUNEIFORM SIGN TAB}",
@@ -873,9 +872,9 @@ ANSI escape code definition.
 Requirements for Japanese Text Layout,
 W3C Working Group Note 11 August 2020
 
-=item L<http://www.ecma-international.org/publications/files/ECMA-ST/Ecma-048.pdf>
+=item L<ECMA-48|https://www.ecma-international.org/wp-content/uploads/ECMA-48_5th_edition_june_1991.pdf>
 
-Control Functions for Coded Character Sets
+ECMA-48: Control Functions for Coded Character Sets
 
 =back
 
